Class: Google::Cloud::Parallelstore::V1::TransferErrorLogEntry

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/parallelstore/v1/parallelstore.rb

Overview

An entry describing an error that has occurred.

Instance Attribute Summary collapse

Instance Attribute Details

#error_details::Array<::String>

Returns A list of messages that carry the error details.

Returns:

  • (::Array<::String>)

    A list of messages that carry the error details.



457
458
459
460
# File 'proto_docs/google/cloud/parallelstore/v1/parallelstore.rb', line 457

class TransferErrorLogEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String

Returns A URL that refers to the target (a data source, a data sink, or an object) with which the error is associated.

Returns:

  • (::String)

    A URL that refers to the target (a data source, a data sink, or an object) with which the error is associated.



457
458
459
460
# File 'proto_docs/google/cloud/parallelstore/v1/parallelstore.rb', line 457

class TransferErrorLogEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end